OffsetSegment

Struct OffsetSegment 

#[repr(C)]
pub struct OffsetSegment { pub offset: U32<LE>, pub segment: U16<LE>, }
Stores an offset and segment pair, in that order. This structure is directly embedded in on-disk structures.

Fields

offset: U32<LE>

The offset in bytes of a symbol within a segment.

segment: U16<LE>

The segment (section) index.

Implementations

Source

impl OffsetSegment

pub fn new(offset: u32, segment: u16) -> Self

Constructor

pub fn offset(&self) -> u32

The offset in bytes of a symbol within a segment.

pub fn segment(&self) -> u16

The segment (section) index.

pub fn as_tuple(&self) -> (u16, u32)

Combines the segment and offset into a tuple. The segment is the first element and the offset is the second element. This order gives a sorting order that sorts by segment first.

pub fn as_u64(&self) -> u64

Combines the segment and offset into a single u64 value, with the segment in the higher-order bits. This allows for efficient comparisons.